@@ -53,7 +53,7 @@ locale="C" # this global variable may be redefined later
 
 class w2mMainWindow(QMainWindow):
     
-    def __init__(self, parent, argv):
+    def __init__(self, parent, argv, locale="C"):
         """
         The constructor
         @param parent a parent window
@@ -66,6 +66,7 @@ class w2mMainWindow(QMainWindow):
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
         self.ui_connections()
+        self.locale=locale
         self.wikiIndex=None
         self.latexComp=None
         self.wb=None
@@ -76,6 +77,12 @@ class w2mMainWindow(QMainWindow):
         self.ui.searchCombo.addItem("Error:")
         return
 
+    def autoOldStyle(self):
+        """
+        @return False as this class has nothing to do with wiki2beamer currently
+        """
+        return False
+    
     def setPdfProductsEnabled(self, state):
         """
         enable/disable the buttons which depend from files output by pdflatex
@@ -120,7 +127,7 @@ class w2mMainWindow(QMainWindow):
         event.acceptProposedAction()
         return
     
-    httpRegexp=re.compile(r"(http://.*/index.php)/\S+")
+    httpRegexp=re.compile(r"(http://.*/index.php)/[.-_\S:]+")
     
     def wa_dropEvent(self, event):
         mimeData = event.mimeData()
@@ -129,7 +136,7 @@ class w2mMainWindow(QMainWindow):
             m=w2mMainWindow.httpRegexp.match(text)
             if m:
                 # get the web page's source
-                text=wikiParser.getWikiContents(text)
+                text=wikiParser.getWikiContents(text)[1]
                 self.ui.wikiDropArea.setPlainText(text)
                 self.wikiIndex=m.group(1)
                 self.ui.wikiIndex.setText(self.wikiIndex)
@@ -194,17 +201,35 @@ class w2mMainWindow(QMainWindow):
         self.imageSet=imageSet
         return
 
+    def getSelected(self, area=None, allSelected=False):
+        """
+        gets the text selected in the drop area, and converts eventually
+        all the line breaks
+        @param area if None, defaults to self.ui.wikiDropArea; else can be
+        another text containing widget
+        @param allSelected : selects everything if True
+        returns the selected contents as a unicode string
+        """
+        if area==None:
+            area=self.ui.wikiDropArea
+        if allSelected:
+            area.selectAll()
+        cursor=area.textCursor()
+        if not cursor.hasSelection():
+            area.selectAll()
+            cursor=area.textCursor()
+        s=unicode(cursor.selectedText())
+        s="\n".join(s.splitlines())
+        return s
+        
+
     def toLatex(self):
         """
         turns the selected contents of the first tab into Latex code which is
         fed into the second tab. If nothing is selected previously, the whole
         contents are selected.
         """
-        cursor=self.ui.wikiDropArea.textCursor()
-        if not cursor.hasSelection():
-            self.ui.wikiDropArea.selectAll()
-            cursor=self.ui.wikiDropArea.textCursor()
-        self.latexSource=unicode(cursor.selectedText())
+        self.latexSource=self.getSelected()
         self.toLatexWait=spinWheelWaitDialog(self, self.stopToLatex, title="Expanding to LaTeX")
         self.toLatexWait.show()
         self.toLThread=toLatexThread(self)
@@ -224,11 +249,7 @@ class w2mMainWindow(QMainWindow):
         a series of links to wiki pages. If nothing is selected previously, the whole
         contents are selected.
         """
-        cursor=self.ui.wikiDropArea.textCursor()
-        if not cursor.hasSelection():
-            self.ui.wikiDropArea.selectAll()
-            cursor=self.ui.wikiDropArea.textCursor()
-        self.inputText=unicode(cursor.selectedText())
+        self.inputText=self.getSelected()
         #initialize a wiki2book instance with the home page of the mediawiki
         if self.wikiIndex==None:
             self.getWikiIndex()
@@ -332,7 +353,8 @@ class w2mMainWindow(QMainWindow):
         self.compileProgress.setWindowTitle("LaTeX compilation")
         self.compileProgress.show()
         self.connect(self.compileProgress, SIGNAL("canceled()"), self.stopPdfLatex)
-        self.latexSource=unicode(self.ui.latexCodeArea.toPlainText())
+        self.latexSource=self.getSelected(area=self.ui.latexCodeArea, 
+                                          allSelected=True)
         self.lcThread=latexCompileThread(self)
         self.lcThread.start()
 
@@ -440,10 +462,8 @@ class l2lThread(QThread):
         fed into the second tab. The first tab is supposed to provide
         a series of links to wiki pages
         """
-        wb=w2book.wiki2book([self.parent().homeUrl], isUrl=True, report=self.reportErr) # the fake homeUrl is there only to get the address of the wiki; as a side-effect, the cache will be loaded with fake data.
+        wb=w2book.wiki2([self.parent().homeUrl], parent=self.parent(), report=self.reportErr) # the fake homeUrl is there only to get the address of the wiki; as a side-effect, the cache will be loaded with fake data.
         wb.reloadCacheIndirect(self.parent().inputText, cbInfo=self.cbInfo)
-        # register the wiki2book structure
-        self.parent().wb=wb
         texSource=("%s" %wb).decode("utf-8")
         self.parent().emit(SIGNAL("latexready"), texSource, True)
 
@@ -466,7 +486,7 @@ class toLatexThread(QThread):
     def run(self):
         #initialize a wiki2book instance with the home page of the mediawiki
         homeUrl=self.parent().wikiIndex.encode("utf-8")+"/fakePage"
-        wb=w2book.wiki2book([homeUrl], isUrl=True, report=False) # the fake homeUrl is there only to get the address of the wiki; as a side-effect, the cache will be loaded with fake data.
+        wb=w2book.wiki2([homeUrl], parent=self.parent(), isUrl=True, report=False) # the fake homeUrl is there only to get the address of the wiki; as a side-effect, the cache will be loaded with fake data.
         wb.reloadCache(self.parent().latexSource)
         latexSource=("%s" %wb).decode("utf-8")
         # register the wiki2book structure
@@ -528,7 +548,7 @@ def run(argv):
     if appTranslator.load("/usr/share/uicilibris/lang/uicilibris_" + locale):
         app.installTranslator(appTranslator)
     
-    w = w2mMainWindow(None,argv)
+    w = w2mMainWindow(None,argv,locale=locale)
     w.show()
     sys.exit(app.exec_())
     
