@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS version="2.0">
 <context>
     <name>MainWindow</name>
     <message>
@@ -153,97 +153,97 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="245"/>
+        <location filename="../uicilibris.ui" line="258"/>
         <source>Latex Log</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="248"/>
+        <location filename="../uicilibris.ui" line="261"/>
         <source>This tab displays the log file output by pdflatex</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="251"/>
+        <location filename="../uicilibris.ui" line="264"/>
         <source>After a run of pdftlatex, errors and warnings emitted during the compilation can be searched in this tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="266"/>
+        <location filename="../uicilibris.ui" line="279"/>
         <source>Find</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="284"/>
+        <location filename="../uicilibris.ui" line="297"/>
         <source>Type a string (or select it in a list) to search it</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="287"/>
+        <location filename="../uicilibris.ui" line="300"/>
         <source>Type a string in the combo box (or select it in the combo&apos;s list) to search it</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="297"/>
+        <location filename="../uicilibris.ui" line="310"/>
         <source>Click here to find the next occurence of the searched string</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="300"/>
+        <location filename="../uicilibris.ui" line="313"/>
         <source>Click &apos;Next&apos; to find the next occurence of the searched string</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="303"/>
+        <location filename="../uicilibris.ui" line="316"/>
         <source>Next</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="316"/>
+        <location filename="../uicilibris.ui" line="329"/>
         <source>Errors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="319"/>
+        <location filename="../uicilibris.ui" line="332"/>
         <source>This tab is for errors raised by Uicilibris</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="322"/>
+        <location filename="../uicilibris.ui" line="335"/>
         <source>Uicilibris can detect a few errors. They are reported in this tab</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="352"/>
+        <location filename="../uicilibris.ui" line="365"/>
         <source>&amp;File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="362"/>
+        <location filename="../uicilibris.ui" line="375"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="373"/>
+        <location filename="../uicilibris.ui" line="386"/>
         <source>&amp;Quit (Ctrl-Q)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="376"/>
+        <location filename="../uicilibris.ui" line="389"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="381"/>
+        <location filename="../uicilibris.ui" line="394"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="386"/>
+        <location filename="../uicilibris.ui" line="399"/>
         <source>User &amp;manual</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="389"/>
+        <location filename="../uicilibris.ui" line="402"/>
         <source>F1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -252,81 +252,232 @@
         <source>Base</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../uicilibris.ui" line="245"/>
+        <source>&amp;Export to another mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../uicilibris.ui" line="242"/>
+        <source>exports text and image files from the cache</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>export</name>
+    <message>
+        <location filename="../export.py" line="66"/>
+        <source>No check of mediawiki has been performed yet</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="67"/>
+        <source>The current mediawiki has been checked as INVALID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="68"/>
+        <source>The current mediawiki has been checked as VALID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="70"/>
+        <source>Mediawiki&apos;s validity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="77"/>
+        <source>No information about login available yet</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="78"/>
+        <source>You are not logged in the mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="79"/>
+        <source>You are logged in the mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="81"/>
+        <source>Authentification state</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="122"/>
+        <source>You are not logged</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="125"/>
+        <source>You are logged</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="128"/>
+        <source>Authentification state undecided</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="142"/>
+        <source>The website is not a mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="145"/>
+        <source>The website is a mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="148"/>
+        <source>Validity state undecided</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>exportDialog</name>
+    <message>
+        <location filename="../export.ui" line="14"/>
+        <source>Export parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="27"/>
+        <source>Mediawiki&apos;s URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="50"/>
+        <source>Name Space</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="79"/>
+        <source>Validation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="184"/>
+        <source>Make checks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="37"/>
+        <source>URL of the mediawiki&apos;s homepage. Begins with &apos;http://&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="60"/>
+        <source>A short word with a colon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="66"/>
+        <source>New:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="181"/>
+        <source>Make a few checks in the target mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="86"/>
+        <source>Login</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="93"/>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="103"/>
+        <source>Your login in this mediawiki</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="113"/>
+        <source>Your password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>uicilibris</name>
     <message>
-        <location filename="../uicilibris" line="208"/>
+        <location filename="../uicilibris" line="211"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="254"/>
+        <location filename="../uicilibris" line="257"/>
         <source>Expanding to LaTeX</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="397"/>
+        <location filename="../uicilibris" line="406"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="282"/>
+        <location filename="../uicilibris" line="291"/>
         <source>Links to LaTeX processing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="330"/>
+        <location filename="../uicilibris" line="339"/>
         <source>processing &apos;%1&apos; ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="375"/>
+        <location filename="../uicilibris" line="384"/>
         <source>Pdflatex failed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="375"/>
+        <location filename="../uicilibris" line="384"/>
         <source>For some reason, Pdflatex failed.&lt;b /&gt;Try to hack around.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="397"/>
+        <location filename="../uicilibris" line="406"/>
         <source>Getting images ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="399"/>
+        <location filename="../uicilibris" line="408"/>
         <source>LaTeX compilation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="412"/>
+        <location filename="../uicilibris" line="421"/>
         <source>getting &apos;%1&apos; ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="430"/>
+        <location filename="../uicilibris" line="439"/>
         <source>Cannot open PDF file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="430"/>
+        <location filename="../uicilibris" line="439"/>
         <source>There is no reachable PDF file. Compile the LaTeX source, or check the error tab.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="442"/>
+        <location filename="../uicilibris" line="451"/>
         <source>Cannot find the temporary files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="442"/>
+        <location filename="../uicilibris" line="451"/>
         <source>There is no temporary files. Please run Pdflatex.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../__init__.py" line="159"/>
+        <location filename="../__init__.py" line="166"/>
         <source>À propos</source>
         <translation type="unfinished"></translation>
     </message>
@@ -346,17 +497,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="279"/>
+        <location filename="../uicilibris" line="288"/>
         <source>Connection to the mediawiki ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="343"/>
+        <location filename="../uicilibris" line="352"/>
         <source>Feature not yet implemented</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="343"/>
+        <location filename="../uicilibris" line="352"/>
         <source>The feature &apos;%1&apos; is not yet implemented. Report a bug to the developers.</source>
         <translation type="unfinished"></translation>
     </message>
