@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr_FR">
+<!DOCTYPE TS><TS version="2.0" language="fr_FR" sourcelanguage="">
 <context>
     <name>MainWindow</name>
     <message>
@@ -158,97 +158,97 @@
         <translation>Explorer le journal</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="245"/>
+        <location filename="../uicilibris.ui" line="258"/>
         <source>Latex Log</source>
         <translation>Journal LaTeX</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="248"/>
+        <location filename="../uicilibris.ui" line="261"/>
         <source>This tab displays the log file output by pdflatex</source>
         <translation>Ce volet montre le journal créé par pdflatex</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="251"/>
+        <location filename="../uicilibris.ui" line="264"/>
         <source>After a run of pdftlatex, errors and warnings emitted during the compilation can be searched in this tab.</source>
         <translation>Après le lancement de pdflatex, les erreurs et les avertissements émis durant la compilation peuvent être consultés dans ce volet.</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="266"/>
+        <location filename="../uicilibris.ui" line="279"/>
         <source>Find</source>
         <translation>Rechercher</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="284"/>
+        <location filename="../uicilibris.ui" line="297"/>
         <source>Type a string (or select it in a list) to search it</source>
         <translation>Écrire un mot (ou le sélectionner dans la liste déroulante) pour le rechercher</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="287"/>
+        <location filename="../uicilibris.ui" line="300"/>
         <source>Type a string in the combo box (or select it in the combo&apos;s list) to search it</source>
         <translation>Écrivez un mot dans le combo (ou sélectionnez-le dans la liste du combo) pour le rechercher</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="297"/>
+        <location filename="../uicilibris.ui" line="310"/>
         <source>Click here to find the next occurence of the searched string</source>
         <translation>Cliquer ici pour trouver l&apos;occurence suivante de la chaîne recherchée</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="300"/>
+        <location filename="../uicilibris.ui" line="313"/>
         <source>Click &apos;Next&apos; to find the next occurence of the searched string</source>
         <translation>Cliquer sur « Suivant » pour trouver l&apos;occurence suivante de la chaîne recherchée</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="303"/>
+        <location filename="../uicilibris.ui" line="316"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="316"/>
+        <location filename="../uicilibris.ui" line="329"/>
         <source>Errors</source>
         <translation>Erreurs</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="319"/>
+        <location filename="../uicilibris.ui" line="332"/>
         <source>This tab is for errors raised by Uicilibris</source>
         <translation>Ce volet est pour les erreurs détectées par Uicilibris</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="322"/>
+        <location filename="../uicilibris.ui" line="335"/>
         <source>Uicilibris can detect a few errors. They are reported in this tab</source>
         <translation>Uicilibris peut déteecter quelques erreurs. Elles sont rapportées dans ce volet</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="352"/>
+        <location filename="../uicilibris.ui" line="365"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="362"/>
+        <location filename="../uicilibris.ui" line="375"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="373"/>
+        <location filename="../uicilibris.ui" line="386"/>
         <source>&amp;Quit (Ctrl-Q)</source>
         <translation>&amp;Quitter (Ctrl-Q)</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="376"/>
+        <location filename="../uicilibris.ui" line="389"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="381"/>
+        <location filename="../uicilibris.ui" line="394"/>
         <source>&amp;About</source>
         <translation>À &amp;propos</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="386"/>
+        <location filename="../uicilibris.ui" line="399"/>
         <source>User &amp;manual</source>
         <translation>&amp;Manuel utilisateur</translation>
     </message>
     <message>
-        <location filename="../uicilibris.ui" line="389"/>
+        <location filename="../uicilibris.ui" line="402"/>
         <source>F1</source>
         <translation>F1</translation>
     </message>
@@ -257,16 +257,172 @@
         <source>Base</source>
         <translation>Base</translation>
     </message>
+    <message>
+        <location filename="../uicilibris.ui" line="245"/>
+        <source>&amp;Export to another mediawiki</source>
+        <translation>&amp;Exporter vers un autre mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../uicilibris.ui" line="242"/>
+        <source>exports text and image files from the cache</source>
+        <translation>exporte les fichiers texte et image du cache</translation>
+    </message>
+</context>
+<context>
+    <name>export</name>
+    <message>
+        <location filename="../export.py" line="66"/>
+        <source>No check of mediawiki has been performed yet</source>
+        <translation>Pas de test de mediawiki tenté jusque là</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="67"/>
+        <source>The current mediawiki has been checked as INVALID</source>
+        <translation>Le mediawiki courant a été testé comme INVALIDE</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="68"/>
+        <source>The current mediawiki has been checked as VALID</source>
+        <translation>Le mediawiki courant a été testé comme VALIDE</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="70"/>
+        <source>Mediawiki&apos;s validity</source>
+        <translation>Validité du mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="77"/>
+        <source>No information about login available yet</source>
+        <translation>Pas d&apos;information au sujet de l&apos;authentification encore</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="78"/>
+        <source>You are not logged in the mediawiki</source>
+        <translation>Vous n&apos;êtes pas logé dans le mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="79"/>
+        <source>You are logged in the mediawiki</source>
+        <translation>Vous êtes logé dans le mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="81"/>
+        <source>Authentification state</source>
+        <translation>État de l&apos;autentification</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="122"/>
+        <source>You are not logged</source>
+        <translation>Vous n&apos;êtes pas logé</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="125"/>
+        <source>You are logged</source>
+        <translation>Vous êtes logé</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="128"/>
+        <source>Authentification state undecided</source>
+        <translation>État de l&apos;autentification inconnu</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="142"/>
+        <source>The website is not a mediawiki</source>
+        <translation>Le site web n&apos;est pas un mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="145"/>
+        <source>The website is a mediawiki</source>
+        <translation>Le site web est un mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.py" line="148"/>
+        <source>Validity state undecided</source>
+        <translation>État de validité inconnu</translation>
+    </message>
+</context>
+<context>
+    <name>exportDialog</name>
+    <message>
+        <location filename="../export.ui" line="14"/>
+        <source>Export parameters</source>
+        <translation>Paramètres d&apos;exportation</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="27"/>
+        <source>Mediawiki&apos;s URL</source>
+        <translation>URL du mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="50"/>
+        <source>Name Space</source>
+        <translation>Espace de nommage</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="79"/>
+        <source>Validation</source>
+        <translation>Validation</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="184"/>
+        <source>Make checks</source>
+        <translation>Lancer les tests</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="37"/>
+        <source>URL of the mediawiki&apos;s homepage. Begins with &apos;http://&apos;</source>
+        <translation>URL de la page d&apos;accueil du mediawiki. Commence par « http:// »</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="40"/>
+        <source>http://</source>
+        <translation type="obsolete">http://</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="60"/>
+        <source>A short word with a colon</source>
+        <translation>Un mot court suivi de « : »</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="66"/>
+        <source>New:</source>
+        <translation>Nouveau:</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="181"/>
+        <source>Make a few checks in the target mediawiki</source>
+        <translation>Lance quelques tests dans le mediawiki cible</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="86"/>
+        <source>Login</source>
+        <translation>Nom d&apos;utilisateur</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="93"/>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="103"/>
+        <source>Your login in this mediawiki</source>
+        <translation>Votre nom d&apos;utilisateur, pour ce mediawiki</translation>
+    </message>
+    <message>
+        <location filename="../export.ui" line="113"/>
+        <source>Your password</source>
+        <translation>Votre mot de passe</translation>
+    </message>
 </context>
 <context>
     <name>uicilibris</name>
     <message>
-        <location filename="../uicilibris" line="208"/>
+        <location filename="../uicilibris" line="211"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="254"/>
+        <location filename="../uicilibris" line="257"/>
         <source>Expanding to LaTeX</source>
         <translation>Expansion en LaTeX</translation>
     </message>
@@ -276,99 +432,99 @@
         <translation type="obsolete">Connexion à %1 ...</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="397"/>
+        <location filename="../uicilibris" line="406"/>
         <source>Cancel</source>
         <translation>Échappement</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="282"/>
+        <location filename="../uicilibris" line="291"/>
         <source>Links to LaTeX processing</source>
         <translation>Traitement des liens pour LaTeX</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="330"/>
+        <location filename="../uicilibris" line="339"/>
         <source>processing &apos;%1&apos; ...</source>
         <translation>Traitement de « %1 » ...</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="375"/>
+        <location filename="../uicilibris" line="384"/>
         <source>Pdflatex failed</source>
         <translation>Échec de Pdflatex</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="375"/>
+        <location filename="../uicilibris" line="384"/>
         <source>For some reason, Pdflatex failed.&lt;b /&gt;Try to hack around.</source>
         <translation>Pour une raison indéterminée, PdfLatex a échoué.&lt;br /&gt;Essayez de bricoler.</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="397"/>
+        <location filename="../uicilibris" line="406"/>
         <source>Getting images ...</source>
         <translation>Récupération des images ...</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="399"/>
+        <location filename="../uicilibris" line="408"/>
         <source>LaTeX compilation</source>
         <translation>Compilation LaTeX</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="412"/>
+        <location filename="../uicilibris" line="421"/>
         <source>getting &apos;%1&apos; ...</source>
         <translation>récupération de « %1 » ...</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="430"/>
+        <location filename="../uicilibris" line="439"/>
         <source>Cannot open PDF file</source>
         <translation>Impossible d&apos;ouvrir e fichier PDF</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="430"/>
+        <location filename="../uicilibris" line="439"/>
         <source>There is no reachable PDF file. Compile the LaTeX source, or check the error tab.</source>
         <translation>Il n&apos;y a pas de fichier PDF disponible. Compilez la source LaTeX, ou voyez le volet d&apos;erreurs.</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="442"/>
+        <location filename="../uicilibris" line="451"/>
         <source>Cannot find the temporary files</source>
         <translation>Impossible de trouver les fichiers provisoires</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="442"/>
+        <location filename="../uicilibris" line="451"/>
         <source>There is no temporary files. Please run Pdflatex.</source>
         <translation>Il n&apos;y a pas de fichiers provisoires. Veuillez lancer Pdflatex.</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../__init__.py" line="159"/>
+        <location filename="../__init__.py" line="166"/>
         <source>À propos</source>
         <translation>À propos</translation>
     </message>
     <message>
         <location filename="../uicilibris" line="90"/>
         <source>Style = Wiki to Book</source>
-        <translation type="unfinished"></translation>
+        <translation>Style=Wiki vers Book</translation>
     </message>
     <message>
         <location filename="../uicilibris" line="91"/>
         <source>Style = Wiki to Article</source>
-        <translation type="unfinished"></translation>
+        <translation>Style=Wiki vers Article</translation>
     </message>
     <message>
         <location filename="../uicilibris" line="92"/>
         <source>Style = Wiki to Beamer</source>
-        <translation type="unfinished"></translation>
+        <translation>Style=Wiki vers Beamer</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="279"/>
+        <location filename="../uicilibris" line="288"/>
         <source>Connection to the mediawiki ...</source>
-        <translation type="unfinished"></translation>
+        <translation>Connexion au mediawiki ...</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="343"/>
+        <location filename="../uicilibris" line="352"/>
         <source>Feature not yet implemented</source>
-        <translation type="unfinished"></translation>
+        <translation>Fonction non encore implémentée</translation>
     </message>
     <message>
-        <location filename="../uicilibris" line="343"/>
+        <location filename="../uicilibris" line="352"/>
         <source>The feature &apos;%1&apos; is not yet implemented. Report a bug to the developers.</source>
-        <translation type="unfinished"></translation>
+        <translation>La fonction %1 n&apos;est pas encore implémentée. Signalez ce bug aux développeurs.</translation>
     </message>
 </context>
 </TS>
