@@ -50,7 +50,12 @@ class wiki2(wikiParser.wikiParser):
         @return contents converted to Latex/Beamer syntax as a single string,
         encoded in utf-8
         """
-        result=self.preamble()
+        # finds the option for Babel, based on the current locale
+        if str(self.parent.locale)[:2]=="fr":
+            babelOpt="frenchb";
+        else:
+            babelOpt="english"
+        result=self.preamble(babelOpt=babelOpt)
         for l in self.convert2(self.lines, self.report, transform=transform2book.transform):
             l=self.processTabular(l)
             l = self.sanitize(l)
@@ -88,7 +93,7 @@ class wiki2(wikiParser.wikiParser):
         return
 
             
-    def preamble(self, documentclass="book"):
+    def preamble(self, documentclass="book", babelOpt="frenchb"):
         """
         @param documentclass: the documentclass to use
         @ return a LaTeX preamble
@@ -101,7 +106,7 @@ class wiki2(wikiParser.wikiParser):
 \\usepackage{ucs}
 \\usepackage{lmodern}
 \\usepackage{graphicx}
-\\usepackage[frenchb]{babel}
+\\usepackage[babelOpt]{babel}
 \\usepackage{hyperref,wrapfig}
 \\usepackage{amssymb}
 \\usepackage{latexsym}
@@ -112,7 +117,7 @@ class wiki2(wikiParser.wikiParser):
 \\newcommand{\\nop}{}
 
 \\begin{document}
-"""
+""".replace("babelOpt", babelOpt)
 
     def postamble(self):
         return """\
@@ -121,13 +126,29 @@ class wiki2(wikiParser.wikiParser):
 
     def sanitize(self, s):
         """
-        @return a sanitized output: get rid of <math>, &amp; etc.
+        @return a sanitized output: get rid of &amp; etc.
         processes the comments left by previous works;
         processes underscores in lines where there is no maths
         turns lines with math-only contents to out-of text formulas
         takes in account url-like words
         """
+        # convert a few html entities introduced by beautifulsoup
         s=s.replace("&quot;","\"")
+        s=s.replace("&amp;lt;math&gt;", "$")
+        s=s.replace("&amp;lt;/math&gt;", "$")
+        s=s.replace("&amp;lt;code&gt;", "\\texttt{")
+        s=s.replace("&amp;lt;/code&gt;", "}")
+        s=s.replace("&amp;lt;ref&gt;", "\\footnote{")
+        s=s.replace("&amp;lt;/ref&gt;", " }")
+        s=s.replace("&amp;lt;references /&gt;", "")
+        s=s.replace("&amp;lt;", "<")
+        s=s.replace("&amp;gt;", ">")
+        s=s.replace("&gt;", ">")
+        s=s.replace("&amp;amp;","\\&")
+        s=s.replace("%", "\\%")
+        s=re.sub(r"\\comment\{(.*)\}",r"%% \1",s)
+        # some mediawiki instances do not provide the same results,
+        # so here is a second pass to translate special markup
         s=s.replace("<math>", "$")
         s=s.replace("</math>", "$")
         s=s.replace("<code>", "\\texttt{")
@@ -135,21 +156,16 @@ class wiki2(wikiParser.wikiParser):
         s=s.replace("<ref>", "\\footnote{")
         s=s.replace("</ref>", " }")
         s=s.replace("<references />", "")
-        s=s.replace("&amp;lt;", "<")
-        s=s.replace("&amp;gt;", ">")
-        s=s.replace("&amp;amp;","\\&")
-        s=s.replace("%", "\\%{}")
-        s=re.sub(r"\\comment\{(.*)\}",r"%% \1",s)
         if "$" not in s:
             s=s.replace("_","\\_")
         if len(s)>2 and s[0]=="$" and s[-1]=="$":
             s="$%s$" %s
         # hyperlinks with an anchor
         olds=s
-        s=re.sub(r"\[(http://[^ \}]+) +([^\}]+)]", r"\\href{\1 }{\mbox{\2} }",s)
+        s=re.sub(r"\[(http://[^ ]+) +(.+)]", r"\\href{\1 }{\mbox{\2} }",s)
         # http urls alone
-        if olds==s: # avoid processing links twice
-            s=re.sub(r"(http://[^ \}]+)", r"\\href{\1 }{\mbox{\1} }",s)
+        # avoid processing links already prefixed by "href{"
+        s=re.sub(r"([^{])(http://[^ ]+)", r"\1\\href{\2 }{\mbox{\2} }",s)
         return s
     
     def convert2(self,lines, report=False, transform=lambda x, y, z: x):
