@@ -34,6 +34,7 @@ from regularExpressions import *
 from BeautifulSoup import BeautifulSoup
 from plugin.plugin import plugins
 from templateParser import imageParser
+import mediawiki
 from PyQt4.QtCore import SIGNAL
 
 wParser=None # global variable: the last and only wikiParser object
@@ -173,8 +174,8 @@ class lineJoiner:
 
             #restore markups like <math></math>, etc.
             for m in ('math', 'code', 'ref'):
-                l=re.sub('&amp;lt;(/?)'+m+'&amp;gt;', r'<\1'+m+'>', l)
-            l=re.sub('"&amp;lt;references */&amp;gt;','<references />',l)
+                l=re.sub('&amp;lt;(/?)'+m+'&gt;', r'<\1'+m+'>', l)
+            l=re.sub('"&amp;lt;references */&gt;','<references />',l)
 
             if (not self.oldWiki2) and l=="" and r and r[-1]!="\n\n" :
                 l="\n\n" # simplify and keep the return codes for LaTeX
@@ -207,7 +208,10 @@ class txtFileCacher:
         self.oldWiki2=oldWiki2
 
     def __str__(self):
-        return "%s" %self._cache
+        result="CACHE:\n=====\n"
+        for k in self._cache.keys():
+            result += " * %15s : %s\n" %(k,self._cache[k][:61])
+        return result
 
     def reset(self):
         """
@@ -355,7 +359,7 @@ class wikiParser:
         @param text an utf-8 string with wiki code.
         @param cbInfo a callback function to display progress messages. It should accept one string as an input.
         """
-        wikiAddresses=re.findall("\[\[([^\]]+)\]\]", text)
+        wikiAddresses=mediawiki.linksInText(text)
         self.cache.reset()
         if cbInfo==None:
             cbInfo=self.toStdErr # default callback
@@ -438,13 +442,16 @@ class wikiParser:
 
     def applyPlugins(self, s):
         """
+        fixes the strings "&lt;math>" and "&lt;/math>", then
         pre-processes a few simple templates which have a precise definition for
         LaTeX, then processes the images.
         @param s the string to be processed
+        @return the processed string
         """
+        s=s.replace("&lt;math>","$")
+        s=s.replace("&lt;/math>","$")
         #== recodes File:.*.jpg, Fichier:.*.jpg, etc. into Image: templates
         s=re.sub(r"\[\[(File|Fichier):([-_0-9a-zA-Z]*)\.(jpg|JPG|png|PNG|gif|GIF)",r"[[Image:\2.\3",s)
-        #print "GRRR", s
         #== the parsers of every plugin are applied, then the image parser
         parsers=map(lambda c: c(), plugins)+[imageParser(imgFun)]
         for parser in parsers:
@@ -492,7 +499,7 @@ class wikiParser:
                 print >> sys.stderr, "'%s'" %completeUrl
             elif callable(self.report) and completeUrl:
                 self.report("'%s'" %completeUrl)
-            text=self.applyPlugins(text) 
+            text=self.applyPlugins(text)
             text=self.wikiTemplates(text)
             text=text.encode("utf-8")
         self.loadUrlLines(text)
